@@ -1,3 +1,4 @@
+/* $Id: icons.c,v 1.1 2004/08/28 19:25:46 dannybackx Exp $ */
 /****************************************************************************
  * This module is mostly all new
  * by Rob Nation
@@ -11,17 +12,31 @@
  *
  ***********************************************************************/
 
-#include "mwm.h"
-#include <XmI/XmXpm.h>
+#include <LTconfig.h>
 
+#include <stdio.h>
+#include <string.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-
 #ifdef HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
 
+#include <X11/Intrinsic.h>
+#include <X11/extensions/shape.h>
+
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+#if XmVERSION >= 2
+#include <Xm/XpmP.h>
+#else
+#include <XmI/XmXpm.h>
+#endif
+
+#include "mwm.h"
+
+
 #define def_bitmap_width 50
 #define def_bitmap_height 50
 static unsigned char def_bitmap_bits[] =
@@ -74,7 +89,7 @@ static unsigned char def_bitmap_bits[] =
  * Oh well.
  */
 static char *
-find_icon_file(char *icon, char *pathlist, int type)
+find_icon_file(const char *icon, const char *pathlist, int type)
 {
     char *path;
     char *dir_end;
@@ -133,7 +148,7 @@ find_icon_file(char *icon, char *pathlist, int type)
 	    pathlist = dir_end + 1;
     }
     /* Hmm, couldn't find the file.  Return NULL */
-    free(path);
+    XtFree(path);
     return NULL;
 }
 
@@ -215,7 +230,7 @@ get_bitmap_file(ScreenInfo *scr, MwmWindow *tmp_win)
 	tmp_win->icon_p_height = 0;
     }
 
-    free(path);
+    XtFree(path);
 }
 
 /*
@@ -225,7 +240,11 @@ static void
 get_xpm_file(ScreenInfo *scr, MwmWindow *tmp_win)
 {
     XWindowAttributes root_attr;
+#if XmVERSION >= 2
+    XpmAttributes xpm_attributes;
+#else
     _LtXpmAttributes xpm_attributes;
+#endif
     XImage *im, *imshape;
     GC gc;
     char *path = NULL;
@@ -237,12 +256,20 @@ get_xpm_file(ScreenInfo *scr, MwmWindow *tmp_win)
     XGetWindowAttributes(dpy, scr->root_win, &root_attr);
     xpm_attributes.colormap = root_attr.colormap;
     xpm_attributes.closeness = 40000;	/* Allow for "similar" colors */
+#if XmVERSION >= 2
+    xpm_attributes.valuemask = XpmSize | XpmReturnPixels | XpmColormap |
+	XpmCloseness;
+#else
     xpm_attributes.valuemask = _LtXpmSize | _LtXpmReturnPixels | _LtXpmColormap |
 	_LtXpmCloseness;
+#endif
 
 #ifdef NONSTANDARD_CONVERTERS
-    if (_LtXpmReadFileToImage(dpy, path, &im, &imshape, &xpm_attributes) ==
-	_LtXpmSuccess)
+#if XmVERSION >= 2
+    if (XpmReadFileToImage(dpy, path, &im, &imshape, &xpm_attributes) == XpmSuccess)
+#else
+    if (_LtXpmReadFileToImage(dpy, path, &im, &imshape, &xpm_attributes) == _LtXpmSuccess)
+#endif
     {
 
 	tmp_win->icon_pixmap = XCreatePixmap(dpy, scr->root_win,
@@ -280,7 +307,7 @@ get_xpm_file(ScreenInfo *scr, MwmWindow *tmp_win)
     }
 #endif
 
-    free(path);
+    XtFree(path);
 }
 
 /*
@@ -488,7 +515,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
     tmp_win->icon_p_height = 0;
     tmp_win->icon_p_width = 0;
 
-    if ((Mwm.icon_decoration & XmICON_IMAGE) && tmp_win->use_client_icon)
+    if ((scr->icon_decoration & XmICON_IMAGE) && tmp_win->use_client_icon)
     {
 	/* First, See if the app supplies its own icon window */
 	if ((tmp_win->icon_p_height == 0) && (tmp_win->icon_p_width == 0) &&
@@ -510,7 +537,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
 	    (tmp_win->icon_p_height == 0) && (tmp_win->icon_p_width == 0))
 	    get_bitmap_file(scr, tmp_win);
     }
-    else if (Mwm.icon_decoration & XmICON_IMAGE)
+    else if (scr->icon_decoration & XmICON_IMAGE)
     {
 	/* First, check for a color pixmap */
 	if (tmp_win->icon_image != NULL &&
@@ -534,7 +561,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
     }
 
     /* If all that failed, use the default */
-    if ((Mwm.icon_decoration & XmICON_IMAGE) &&
+    if ((scr->icon_decoration & XmICON_IMAGE) &&
 	(tmp_win->icon_p_height == 0) && (tmp_win->icon_p_width == 0))
     {
 	tmp_win->icon_pixmap = XCreateBitmapFromData(dpy,
@@ -549,7 +576,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
     if (tmp_win->flags & SHAPED_ICON)
 	tmp_win->icon_border_width = 0;
     else
-	tmp_win->icon_border_width = Mwm.frame_border_width;
+	tmp_win->icon_border_width = scr->frame_border_width;
 
     /* figure out the icon label size */
     tmp_win->icon_t_width =
@@ -595,7 +622,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
 			     ExposureMask | KeyPressMask | EnterWindowMask |
 			     FocusChangeMask);
 
-    if (Mwm.icon_decoration & (XmICON_LABEL | XmICON_ACTIVELABEL))
+    if (scr->icon_decoration & (XmICON_LABEL | XmICON_ACTIVELABEL))
     {
 	tmp_win->icon_w =
 	    XCreateWindow(dpy, scr->root_win,
@@ -607,7 +634,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
     else
 	tmp_win->icon_w = None;
 
-    if (Mwm.icon_decoration & XmICON_IMAGE)
+    if (scr->icon_decoration & XmICON_IMAGE)
     {
         /* int i; */
 
@@ -696,7 +723,7 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
 				  valuemask, &attributes);
 
 		XSaveContext(dpy, tmp_win->icon_borders[i],
-			     MwmContext, (_Xconst char *)tmp_win);
+			     MwmContext, (XPointer)tmp_win);
 	    }
 	}
 	else
@@ -721,14 +748,14 @@ ICON_CreateWindow(ScreenInfo *scr, MwmWindow *tmp_win, int def_x, int def_y)
 
     if (tmp_win->icon_w != None)
     {
-	XSaveContext(dpy, tmp_win->icon_w, MwmContext, (_Xconst char *)tmp_win);
+	XSaveContext(dpy, tmp_win->icon_w, MwmContext, (XPointer)tmp_win);
 	XDefineCursor(dpy, tmp_win->icon_w, scr->cursors[DEFAULT_CURS]);
 	grab_icon_buttons(scr, tmp_win, tmp_win->icon_w);
 	grab_icon_keys(scr, tmp_win, tmp_win->icon_w);
     }
     if (tmp_win->icon_pixmap_w != None)
     {
-	XSaveContext(dpy, tmp_win->icon_pixmap_w, MwmContext, (_Xconst char *)tmp_win);
+	XSaveContext(dpy, tmp_win->icon_pixmap_w, MwmContext, (XPointer)tmp_win);
 	XDefineCursor(dpy, tmp_win->icon_pixmap_w, scr->cursors[DEFAULT_CURS]);
 	grab_icon_buttons(scr, tmp_win, tmp_win->icon_pixmap_w);
 	grab_icon_keys(scr, tmp_win, tmp_win->icon_pixmap_w);
@@ -751,7 +778,7 @@ ICON_DrawWindow(ScreenInfo *scr, MwmWindow *tmp)
     if (tmp->icon_pixmap_w != None)
 	MISC_FlushExpose(tmp->icon_pixmap_w);
 
-    if (tmp == scr->mwm_highlight && (Mwm.icon_decoration & XmICON_ACTIVELABEL)
+    if (tmp == scr->mwm_highlight && (scr->icon_decoration & XmICON_ACTIVELABEL)
  && tmp->icon_active_label != NoName && tmp->icon_active_label != NULL
       && tmp->icon_active_label[0] != '\0')
 	label = tmp->icon_active_label;
@@ -925,7 +952,7 @@ ICON_DrawWindow(ScreenInfo *scr, MwmWindow *tmp)
 	char *label;
 
 	if (tmp == scr->mwm_highlight &&
-	    (Mwm.icon_decoration & XmICON_ACTIVELABEL) &&
+	    (scr->icon_decoration & XmICON_ACTIVELABEL) &&
 	    tmp->icon_active_label != NoName &&
 	    tmp->icon_active_label != NULL &&
 	    tmp->icon_active_label[0] != '\0')
@@ -979,7 +1006,7 @@ ICON_UpdateWindow(ScreenInfo *scr, MwmWindow *tmp, Boolean force)
 	return;
 
     if ((force || (tmp == scr->mwm_highlight &&
-	 (Mwm.icon_decoration & XmICON_ACTIVELABEL))) &&
+	 (scr->icon_decoration & XmICON_ACTIVELABEL))) &&
 	tmp->icon_active_label != NoName &&
 	tmp->icon_active_label != NULL &&
 	tmp->icon_active_label[0] != '\0')
