@@ -1,9 +1,9 @@
 /**
  *
- * $Id: XmI.h,v 1.41 2001/03/16 13:47:25 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/include/Motif-2.1/XmI/XmI.h,v 1.3 2005/03/26 19:35:34 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -46,6 +46,10 @@
 #include <Xm/Text.h>
 #include <XmI/MacrosI.h>
 
+#ifdef	USE_XFT
+#include <X11/Xft/Xft.h>
+#endif
+
 /*
  * extra resources
  */
@@ -58,10 +62,54 @@
 /*
  * STRING AND FONTLIST INTERNALS
  */
-struct _XmFontListRec {
-    char *tag;
-    XmFontType type;
-    XtPointer font;
+extern XmFontList __XmFontListAlloc(int numberOfEntries);
+extern void _XmFontListEntryFree(XmFontListEntry entry);
+XmFontListEntry _XmFontListEntryCreate(void);
+
+/* Experimental _XmRenderTableFinalise() */
+void __XmRenderTableFinalise(Widget, XmFontList, _XmString);
+void _XmRenderTableFinalise(Widget, XmFontList, XmString);
+void _XmRenderTableFinaliseTag(Widget, XmFontList, char *);
+
+XmRenderTable _XmRenderTablePushRendition(XmRenderTable, XmRendition);
+XmRenderTable _XmRenderTablePopRendition(XmRenderTable, XmRendition);
+
+typedef struct __XmRenditionRec {
+	char		*tag;
+	XmFontType	type;
+	XFontSet	font;
+	int		count;
+	Pixel		rendition_background,
+			rendition_foreground;
+	char		*font_name;
+	unsigned char	load_model,
+			strike_thru_type,
+			underline_type;
+	XmTabList	tab_list;
+	Display		*dpy;
+#ifdef	USE_XFT
+	/* experimental - use of Xft, see http://fontconfig.org */
+	char		*font_style,
+/*			*family,	Use font_name instead. */
+			*font_foundry,
+			*font_encoding;
+	int		font_size,
+			pixel_size,
+			font_slant,
+			font_spacing,
+			font_weight;
+	XftPattern	*pattern;
+	XftFont		*xft_font;
+	XftColor	xft_foreground, xft_background;
+	int		font_average_width,	/* Calculated by LessTif,	*/
+			font_average_height;	/* depend only on xft_font	*/
+#endif
+} *_XmRendition;
+
+struct __XmRenderTableRec {
+	unsigned int	count;
+	Display		*dpy;
+	_XmRendition	*renditions;	/* An array of pointers */
 };
 
 struct _XmFontListContextRec {
@@ -107,6 +155,15 @@ struct _XmtStringContextRec {
     Boolean separator;
 };
 
+struct __XmParseMappingRec {
+	XtPointer	client_data;
+	XmIncludeStatus	include_status;
+	XmParseProc	invoke_parse_proc;
+	XtPointer	pattern;
+	XmTextType	pattern_type;
+	XmString	substitute;
+};
+
 /* ADDED FOR EXTERNAL FORM */
 #define XmSTRING_COMPONENT_XMSTRING     (XmSTRING_COMPONENT_LOCALE_TEXT + 1)
 #define XmSTRING_TAG                    0xDFU
@@ -122,11 +179,6 @@ typedef unsigned char XmIMInputPolicy;
 #define	IP_PER_SHELL		2
 
 void _XmImSendSpot(Widget w);
-#if XmVERSION == 1
-XIC XmImGetXIC(Widget w, XmIMInputPolicy input_policy,
-           ArgList args, Cardinal num_args);
-XIC XmImSetXIC(Widget w, XIC xic);
-#endif
 
 /*
  * GENERIC PROTOTYPES
@@ -281,6 +333,10 @@ void _XmManagerInstallMnemonic(Widget m, Widget w, KeySym mn);
 void _XmManagerUninstallAccelerator(Widget m, Widget w);
 void _XmManagerUninstallMnemonic(Widget m, Widget w);
 
+
+/* for MapEvent.c */
+int _XmMapKeyEvents(String str, int **eventType, KeySym **keysym, Modifiers **modifiers);
+
 /* for ScrolledW */
 /* T. Straumann: */
 void _XmScrolledWPreferredSize(Widget w, Widget instigator,
@@ -301,6 +357,9 @@ void _XmPushButtonSetTranslation(Widget, int);
 void _XmChangeVSB(XmTextWidget w, XmTextPosition pos);
 void _XmRedisplayHBar(XmTextWidget w, int offset);
 int  _XmFontCalculateAverageCharacterWidth(Widget w, XFontStruct *fs);
+
+void _XmCursorOverstrike(Widget w); /* formerly: CursorOverstrike */
+
 /* Traversal */
 void _XmSetFocusResetFlag(Widget w, Boolean value);
 Boolean _XmGetFocusResetFlag(Widget w);
@@ -337,12 +396,13 @@ void _XmAddBackgroundToColorCache(Screen *screen, Colormap color_map,
                                   String background_spec,
                                   int rgb_fallback, XrmValue *val);
 void _XmInvalidateColorCache(Boolean default_only);
+void _XmPickupUnspecifiedPixmaps(Display *dpy);
 
 /* XmString */
 
 void _XmStringBaselines(XmFontList fontlist, _XmString string,
                         Position y, Dimension *baselines);
-
+void _XmStringUpdate(XmFontList fontlist, _XmString string);
 /*
  * Behaviour control for XmFormLayout, XmRowColumnLayout.
  * This is their second parameter.
@@ -384,86 +444,71 @@ void _XmDrawSquareButton(Widget w, int x, int y, int size,
 void _XmDrawDiamondButton(Widget w, int x, int y, int size,
                           GC top_gc, GC bottom_gc, GC select_gc, Boolean fill);
 
+void _XmDrawPolygonShadow(Display *display, Drawable drawable,
+                          GC top_gc, GC bottom_gc, XPoint *points, int point_count,
+                          Dimension shadow_thickness, unsigned char shadow_type);
 
-#if XmVERSION >= 2
-/* from Xmos.c: 
-   private, but exported stuff from Motif 1.2 which is used within LessTif,
-   also for the 2.x libs */
 
+/*
+ * From Xmos.c: private, but exported stuff from Motif 1.2
+ * which is used within LessTif, also for the 2.x libs
+ */
 XmString 
-_XmOSGetLocalizedString(char *reserved,
-			Widget w,
-			String resourceName,
-			String value);
-
+_XmOSGetLocalizedString(char *reserved, Widget w, String resourceName, String value);
 int _XmMicroSleep(long secs);
-
 String _XmOSGetHomeDirName(void);
-
-void 
-_XmSleep(unsigned int secs);
-
+String _XmOSInitPath(String file_name, String env_pathname, Boolean *user_path);
+void _XmSleep(unsigned int secs);
 String _XmOSGetHomeDirName(void);
-
-int 
-_XmOSFileCompare(XmConst void *sp1,
-                 XmConst void *sp2);
-
-
-void 
-_XmOSQualifyFileSpec(String dirSpec,
-                     String filterSpec,
-                     String *pQualifiedDir,
-                     String *pQualifiedPattern);
-
-String 
-_XmOSFindPatternPart(String fileSpec);
-
-void 
-_XmOSGetDirEntries(String qualifiedDir,
-                   String matchPattern,
-                   unsigned char fileType,
-                   Boolean matchDotsLiterally,
-                   Boolean listWithFullPath,
-                   String **pEntries,
-                   unsigned int *pNumEntries,
-                   unsigned int *pNumAlloc);
-
-void 
-_XmOSBuildFileList(String dirPath,
-                   String pattern,
-                   unsigned char typeMask,
-                   String **pEntries,
-                   unsigned int *pNumEntries,
-                   unsigned int *pNumAlloc);
+int _XmOSFileCompare(XmConst void *sp1, XmConst void *sp2);
+void _XmOSQualifyFileSpec(String dirSpec, String filterSpec,
+		String *pQualifiedDir, String *pQualifiedPattern);
+String _XmOSFindPatternPart(String fileSpec);
+void _XmOSGetDirEntries(String qualifiedDir, String matchPattern,
+		unsigned char fileType, Boolean matchDotsLiterally,
+		Boolean listWithFullPath, String **pEntries,
+		unsigned int *pNumEntries, unsigned int *pNumAlloc);
+void _XmOSBuildFileList(String dirPath, String pattern,
+		unsigned char typeMask, String **pEntries,
+		unsigned int *pNumEntries, unsigned int *pNumAlloc);
 
 
 /* The following are definitions for 2.x stuff, work in progress.
    Since are not public they can be changed at any time ... ?!? */
-struct __XmTabRec {
-    float value;
-    unsigned char units;
-    XmOffsetModel offset_model;
-    unsigned char alignment;
-    char *decimal;
+struct _XmTabRec {
+	float value;
+	unsigned char units;
+	XmOffsetModel offset_model;
+	unsigned char alignment;
+	char *decimal;
 };
 
-struct __XmTabListRec {
-    float value;
-    unsigned char units;
-    XmOffsetModel offset_model;
-    unsigned char alignment;
-    char *decimal;
+struct _XmTabListRec {
+	struct _XmTabRec	**tabs;
+	int			count;
 };
 
-
 /* defined in Trait.c, but used outside; not a symbol from OSF/Motif */
 void _XmInitTraits(void);
 
-#endif /* XmVERSION >= 2 */
+#ifdef	USE_XFT
+/*
+ * XftDraw cache functions, implemented in lib/Xm/FontList.c
+ */
+XftDraw * _XmXftDrawCreate(Display *dpy, Window w);
+void _XmXftDrawDestroy(Display *dpy, Window w, XftDraw *d);
+void _XmXftDrawString(Display *dpy, Window wd, XmRendition r, int bpc, Position x, Position y, char *s, int len);
+void _XmXftFontAverageWidth(Widget w, XtPointer f, int *wid, int *ht);
+#endif
 
 /* from Vendor.c */
 extern Boolean _LtCheckClassOfVendorShell(Widget w);
 
+/*
+ *   Some general purpose macros follow:
+ */
+#define _XmMin(a,b) (((a)<(b))?(a):(b))
+#define _XmMax(a,b) (((a)>(b))?(a):(b))
+
 
 #endif /* _XMI_XMI_H */
