@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/CascadeB.c,v 1.161 2002/11/02 07:28:47 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/CascadeB.c,v 1.1 2004/08/28 19:22:43 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
  * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/CascadeB.c,v 1.161 2002/11/02 07:28:47 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/CascadeB.c,v 1.1 2004/08/28 19:22:43 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -347,13 +347,14 @@ place_cascade(Widget w)
 static void
 size_cascade(Widget w)
 {
-    int dummy;
-    unsigned width, height;
+    int		dummy;
+    Window	dummyw;
+    unsigned	width, height;
 
     if (CB_CascadePixmap(w) > XmUNSPECIFIED_PIXMAP)
     {
 	XGetGeometry(XtDisplay(w), CB_CascadePixmap(w),
-		     (Window *)&dummy, &dummy, &dummy,
+		     &dummyw, &dummy, &dummy,
 		     &width, &height, (unsigned *)&dummy, (unsigned *)&dummy);
 	CB_Cascade_width(w) = width;
 	CB_Cascade_height(w) = height;
