@@ -1,6 +1,6 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/FileSB.c,v 1.3 2004/09/27 19:15:51 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/FileSB.c,v 1.4 2004/10/17 09:24:53 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  * Copyright  1997, 1998, 1999, 2000, 2001, 2002, 2004 LessTif Development Team
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/FileSB.c,v 1.3 2004/09/27 19:15:51 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/FileSB.c,v 1.4 2004/10/17 09:24:53 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -203,7 +203,6 @@ static XtResource resources[] =
 	sizeof(int), SBOffset(list_item_count),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED
     },
-#if XmVERSION > 1
 /*
  *	XmNpathMode
  *	Specifies whether or not an additional text field will be used 
@@ -237,7 +236,6 @@ static XtResource resources[] =
 	sizeof(XmString), Offset(dir_text_label_string),
 	XmRImmediate, (XtPointer)XmUNSPECIFIED
     },
-#endif
 };
 
 /* Synthetic resources */
@@ -552,7 +550,6 @@ initialize(Widget request, Widget new_w,
     argc++;
     XtSetValues(SB_ListLabel(new_w), argl, argc);
 
-#if XmVERSION > 1
     /*
      * directory label
      */
@@ -568,7 +565,6 @@ initialize(Widget request, Widget new_w,
     {
 	FS_DirTextLabelString(new_w) = XmStringCopy(FS_DirTextLabelString(new_w));
     }
-#endif
 
     /*
      * filter label
@@ -605,7 +601,6 @@ initialize(Widget request, Widget new_w,
     	XmNlabelString, SB_ApplyLabelString(new_w),
     	NULL);
 
-#if XmVERSION > 1
     if (FS_PathMode(new_w) == XmPATH_MODE_RELATIVE) {
 	FS_DirTextLabel(new_w) = _XmBB_CreateLabelG(new_w,
 					       FS_DirTextLabelString(new_w),
@@ -616,7 +611,6 @@ initialize(Widget request, Widget new_w,
 	XtSetValues(FS_DirTextLabel(new_w), argl, argc);
 	XtManageChild(FS_DirTextLabel(new_w));
     }
-#endif
 
     FS_FilterLabel(new_w) = _XmBB_CreateLabelG(new_w,
 					       FS_FilterLabelString(new_w),
@@ -636,7 +630,6 @@ initialize(Widget request, Widget new_w,
     XtSetValues(FS_DirListLabel(new_w), argl, argc);
     XtManageChild(FS_DirListLabel(new_w));
 
-#if XmVERSION > 1
     if (FS_PathMode(new_w) == XmPATH_MODE_RELATIVE) {
 	/*
 	 * directory text
@@ -654,7 +647,6 @@ initialize(Widget request, Widget new_w,
 
 	XtManageChild(FS_DirText(new_w));
      }
-#endif
 
     /*
      * filter text
@@ -1360,10 +1352,8 @@ geoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 	    MGR_Children(_w)[i] != FS_FilterLabel(_w) &&
 	    MGR_Children(_w)[i] != FS_FilterText(_w) &&
 	    MGR_Children(_w)[i] != FS_DirListLabel(_w) &&
-#if XmVERSION > 1
 	    MGR_Children(_w)[i] != FS_DirText(_w) &&
 	    MGR_Children(_w)[i] != FS_DirTextLabel(_w) &&
-#endif
 	    (FS_DirList(_w)
 	     ? MGR_Children(_w)[i] != XtParent(FS_DirList(_w))
 	     : True))
@@ -1394,10 +1384,8 @@ geoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 	    MGR_Children(_w)[i] != FS_FilterLabel(_w) &&
 	    MGR_Children(_w)[i] != FS_FilterText(_w) &&
 	    MGR_Children(_w)[i] != FS_DirListLabel(_w) &&
-#if XmVERSION > 1
 	    MGR_Children(_w)[i] != FS_DirText(_w) &&
 	    MGR_Children(_w)[i] != FS_DirTextLabel(_w) &&
-#endif
 	    (FS_DirList(_w)
 	     ? MGR_Children(_w)[i] != XtParent(FS_DirList(_w))
 	     : True))
@@ -1427,7 +1415,6 @@ geoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 	}
     }
 
-#if XmVERSION > 1
     if (FS_PathMode(_w) == XmPATH_MODE_RELATIVE) {
 	if (FS_DirTextLabel(_w) && XtIsManaged(FS_DirTextLabel(_w))) {
 		nrows++;
@@ -1448,18 +1435,6 @@ geoMatrixCreate(Widget _w, Widget _from, XtWidgetGeometry *_pref)
 		nrows++;
 	}
     }
-#else
-    if (FS_FilterLabel(_w) && XtIsManaged(FS_FilterLabel(_w)))
-    {
-	nrows++;
-    }
-
-    if (FS_FilterText(_w) && XtIsManaged(FS_FilterText(_w)))
-    {
-	nrows++;
-    }
-
-#endif
 
     if ((FS_DirListLabel(_w) && XtIsManaged(FS_DirListLabel(_w))) ||
 	(SB_ListLabel(_w) && XtIsManaged(SB_ListLabel(_w))))
@@ -1956,7 +1931,6 @@ noGeoRequest(XmGeoMatrix _geoSpec)
 /******************************* SEARCHING **********************************/
 
 
-#if XmVERSION > 1
 /* Keep it short and simple - make it a function (instead of a macro)
    for easier debugging purposes but give it a more than reasonable chance
    to be optimized out (or inlined in :-)  ... */
@@ -1982,8 +1956,6 @@ FileIsHidden(String name)
 		return False;
 	}
 }
-#endif
-
 
 static void
 defaultDirSearchProc(Widget widget,
@@ -2024,7 +1996,6 @@ defaultDirSearchProc(Widget widget,
     max = 64;
     table = (XmString *)XtCalloc(max, sizeof(XmString));
    
-#if XmVERSION > 1
     /* we use two versions of this loop for better performance */
     if (FS_FileFilterStyle(widget)==XmFILTER_HIDDEN_FILES) {
 
@@ -2049,7 +2020,6 @@ defaultDirSearchProc(Widget widget,
 	numents = visible;
     }  /* XmFILTER_HIDDEN_FILES */
     else
-#endif
     for (i = 0; i < numents; i++)
     {
 	if (i == max)
@@ -2132,7 +2102,6 @@ defaultFileSearchProc(Widget widget, XtPointer data)
     max = 64;
     table = (XmString *)XtCalloc(max, sizeof(XmString));
 
-#if XmVERSION > 1
     /* we use two versions of this loop for better performance */
     if (FS_FileFilterStyle(widget)==XmFILTER_HIDDEN_FILES) {
 
@@ -2157,7 +2126,6 @@ defaultFileSearchProc(Widget widget, XtPointer data)
     numents = visible;
     } /* XmFILTER_HIDDEN_FILES */
     else
-#endif
      for (i = 0; i < numents; i++)
         {
    	 if (i == max)
