@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.130 2003/10/23 08:33:00 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/TextOut.c,v 1.7 2005/03/29 15:28:00 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/TextOut.c,v 1.130 2003/10/23 08:33:00 amai Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm-2.1/TextOut.c,v 1.7 2005/03/29 15:28:00 dannybackx Exp $";
 
 /* Do NOT use this (USE_XT_GC) :
  * it requires setting all the dynamic GC fields before every use of
@@ -66,12 +66,7 @@ static void Draw(XmTextWidget w, LineNum num, XmTextPosition start, XmTextPositi
 #define Offset(field) XtOffsetOf(XmTextInnerRec, inner.out.field)
 
 
-#if XmVERSION > 1
 #define	USE_AVERAGE_WIDTH 1
-#else
-/* same behavior as XmTextField.*/
-#undef	USE_AVERAGE_WIDTH
-#endif
 
 #undef	Out_FontTextWidth
 #define	Out_FontTextWidth(o,s,l)	(int)_XmOut_FontTextWidth(o, s, l)
@@ -97,8 +92,10 @@ static XtResource output_resources[] =
 	sizeof(Boolean), Offset(cursor_position_visible),
 	XmRImmediate, (XtPointer)True
     },
-#if (XmVERSION > 1) && defined(USE_XFT)
-    /* Note that the right order is important here ! */
+    /*
+     * FontList and RenderTable resources :
+     * Note that the right order is important here !
+     */
     {
 	"keep.off", "Keep.off", XmRBoolean,
 	sizeof(Boolean), Offset(check_set_render_table),
@@ -114,13 +111,9 @@ static XtResource output_resources[] =
 	sizeof(XmFontList), Offset(fontlist),
 	XmRCallProc, (XtPointer)_XmTextOutSetRenderTable
     },
-#else
-    {
-	XmNfontList, XmCFontList, XmRFontList,
-	sizeof(XmFontList), Offset(fontlist),
-	XmRImmediate, (XtPointer)XmUNSPECIFIED
-    },
-#endif
+    /*
+     * End of the fontList and renderTable resources
+     */
     {
 	XmNresizeHeight, XmCResizeHeight, XmRBoolean,
 	sizeof(Boolean), Offset(resizeheight),
@@ -171,7 +164,6 @@ static XtResource output_resources[] =
 extern int
 _XmFontCalculateAverageCharacterWidth(Widget w, XFontStruct *fs)
 {
-	/*CP: The following is more or less what the XFree86 people have suggested. */
 	unsigned long width;
 	Atom atom;
 
@@ -185,19 +177,18 @@ _XmFontCalculateAverageCharacterWidth(Widget w, XFontStruct *fs)
 			&& XGetFontProperty(fs, atom, &width) && width) {
 		width = (width + 5) / 10; /*CP: just to round it up slightly */
 	} else if ((! XGetFontProperty(fs, XA_QUAD_WIDTH, &width)) || width == 0) {
-		/*CP: Yes, even if the property is available it could be 0 - as per XF86 people */
-		/*So we will will use the character "x" */
-		if ( fs->per_char &&  fs->min_char_or_byte2 <= 'x' &&
-				fs->max_char_or_byte2 >= 'x')
-				/* i.e. we have data for x */
-			width = fs->per_char['a' - fs->min_char_or_byte2].width;
+		/*
+		 * Use the width of '0' if that's available, otherwise the maximum width
+		 * like the manual page of XmText says.
+		 */
+		if (fs->per_char && fs->min_char_or_byte2 <= '0' && fs->max_char_or_byte2 >= '0')
+			width = fs->per_char['0' - fs->min_char_or_byte2].width;
 		else
-			width = fs->max_bounds.width / 2 ;                                          
+			width = fs->max_bounds.width ;                                          
 	}
 	return width;
 }
 
-
 /* FIX ME - this thing is clearly overly simplistic. */
 /* I think it should :
  *    - grab a fontset whenever it can (bypassing fonts)
@@ -218,6 +209,7 @@ FontInit(XmTextWidget w)
 	int i;
 
 	DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "FontInit(fontlist %p)\n", oldlist));
+	DEBUGOUT(_LtDebugPrintRenderTable("FontInit(): ", oldlist));
 
 	/* This part is probably all wrong ... FIX ME */
 	for (i = 0; Out_FontList(o)->renditions[i]->tag != NULL; i++) {
@@ -319,16 +311,20 @@ FontInit(XmTextWidget w)
 			(fs->max_bounds.width + fs->min_bounds.width) / 2;
 		Out_UseFontSet(o) = False;
 		Out_Font(o) = fs;
+		Out_Font_Ascent(o) = Out_FontAscent(o);
+		Out_Font_Descent(o) = Out_FontDescent(o);
 #ifdef	USE_XFT
 	} else if (entry->type == XmFONT_IS_XFT) {
 		Out_FontAverageWidth(o) = Out_XftFont(o)->max_advance_width;
 		Out_FontAverageWidth(o) = entry->font_average_width;	/* FIX ME HACK */
-		Out_UseFontSet(o) = False;
+		Out_UseFontSet(o) = False;	/* FIX ME now sure what this means now */
+		Out_Font_Ascent(o) = Out_FontAscent(o);
+		Out_Font_Descent(o) = Out_FontDescent(o);
 #endif
-	} else {			/* XmFONT_IS_FONTSET */
+	} else if (entry->type == XmFONT_IS_FONTSET) {
 		XFontStruct **fsl;
 		char **nl;
-		int r, i, max, min;
+		int r, i, max, min, ma, md;
 
 		r = XFontsOfFontSet((XFontSet)entry->font, &fsl, &nl);
 		DEBUGOUT(_LtDebug(__FILE__, (Widget)w, "XFontsOfFontSet : %d\n", r));
@@ -336,45 +332,48 @@ FontInit(XmTextWidget w)
 			DEBUGOUT(_LtDebug0(__FILE__, NULL, "\t%s\n", nl[i]));
 		}
 
-		/* FIX ME - just pick the first one */
 		if (r == 0) {
 			DEBUGOUT(_LtDebug(__FILE__, NULL, "No font in fontset\n"));
 			abort();
 		}
 
-		fs = fsl[0];
 		/* correct calculation */
-		max = 0; min = INT_MAX;
+		ma = md = max = 0; min = INT_MAX;
 		for(i=0; i<r; i++) {
 			if (fsl[i]->max_bounds.width  > max)
 				max = fsl[i]->max_bounds.width;
 			if (fsl[i]->min_bounds.width  < min)
 				min = fsl[i]->min_bounds.width;
+			if (fsl[i]->max_bounds.ascent > ma)
+				ma = fsl[i]->max_bounds.ascent;
+			if (fsl[i]->max_bounds.descent > md)
+				md = fsl[i]->max_bounds.descent;
 		}
 		Out_FontAverageWidth(o) = (max + min) / 2;
-		Out_Font(o) = fs;
+		Out_Font_Ascent(o) = ma;
+		Out_Font_Descent(o) = md;
 
-	/*	Out_UseFontSet(o) = True;	*/
+		/* Just pick the first one */
+		Out_Font(o) = fsl[0];
+
+		Out_UseFontSet(o) = True;
+	} else {
+		/* This is not supposed to happen. */
+		_XmWarning((Widget)w, "XmText FontInit: untreated rendition type\n");
 	}
 
-	if ( Out_FontAverageWidth(o) <= 0 ) {
+	if (Out_FontAverageWidth(o) <= 0) {
 		Out_FontAverageWidth(o) = _XmFontCalculateAverageCharacterWidth((Widget)w, fs);
 	}
 	Out_TabWidth(o) = 8 * Out_FontAverageWidth(o);
-#if 0
-	/*
-	 * These fields are never used.
-	 */
-	Out_Font_Ascent(o) = Out_FontAscent(o);
-	Out_Font_Descent(o) = Out_FontDescent(o);
-#endif
-	Out_FontHeight(o) = Out_FontAscent(o) + Out_FontDescent(o);
+	Out_FontHeight(o) = Out_Font_Ascent(o) + Out_Font_Descent(o);
 	Out_CursorHeight(o) = Out_FontHeight(o);
 
+
 	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		"FontInit - fl %p font %p : ascent=%d descent=%d height=%d avewidth=%d\n",
 		Out_FontList(o), Out_Font(o),
-		Out_FontAscent(o), Out_FontDescent(o),
+		Out_Font_Ascent(o), Out_Font_Descent(o),
 		Out_FontHeight(o), Out_FontAverageWidth(o)));
 }
 
@@ -596,23 +595,26 @@ GCPixmap(XmTextWidget tw)
 static void
 GCClip(XmTextWidget w)
 {
-    OutputData o = Text_OutputData(w);
-    XRectangle clip;
+	OutputData o = Text_OutputData(w);
+	XRectangle clip;
 
-    clip.x = 0;
-    clip.y = 0;
-    clip.width = XtWidth(w) - ( Out_RightMargin(o) + Out_LeftMargin(o) );
-    clip.height = XtHeight(w) - ( Out_TopMargin(o) + Out_BottomMargin(o) );
+	clip.x = 0;
+	clip.y = 0;
+	clip.width = XtWidth(w) - ( Out_RightMargin(o) + Out_LeftMargin(o) );
+	clip.height = XtHeight(w) - ( Out_TopMargin(o) + Out_BottomMargin(o) );
 
-#ifdef	DANNY
-    fprintf(stderr, "XmText GCClip wid %d ht %d\n", clip.width, clip.height);
-#endif
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
+				"XmText GCClip gc %p wid %d ht %d (%d - %d - %d, %d - %d - %d)\n",
+				Out_DrawGC(o),
+				clip.width, clip.height,
+				XtWidth(w), Out_RightMargin(o), Out_LeftMargin(o),
+				XtHeight(w), Out_TopMargin(o), Out_BottomMargin(o)));
 
-    /* These calls change the GCs */
-    XSetClipRectangles(XtDisplay((Widget)w), Out_DrawGC(o),
-	   Out_LeftMargin(o), Out_TopMargin(o), &clip, 1, Unsorted);
+	/* These calls change the GCs */
+	XSetClipRectangles(XtDisplay((Widget)w), Out_DrawGC(o),
+			Out_LeftMargin(o), Out_TopMargin(o), &clip, 1, Unsorted);
 
-    GCPixmap(w);
+	GCPixmap(w);
 }
 
 
@@ -664,7 +666,7 @@ SizeRecalc(XmTextWidget w)
 	/* Y offset for a row R is calculated as Out_YDraw(o) - R*fontHeight,
 	 * and I add FontAscent here because y positions for fonts are
 	 * measured from the baseline of the font. */
-	Out_YDraw(o) = Out_TopMargin(o) + Out_FontAscent(o);
+	Out_YDraw(o) = Out_TopMargin(o) + Out_Font_Ascent(o);
 
 	if (Text_EditMode(w) == XmSINGLE_LINE_EDIT) {
 		Out_Rows(o) = 1;
@@ -676,8 +678,8 @@ SizeRecalc(XmTextWidget w)
 			Out_Rows(o) = 1;
 		}
 	}
-	if (XtHeight(w) < (Out_TopMargin(o) + Out_BottomMargin(o)
-				+ Out_FontHeight(o) * Out_Rows(o))) {
+	if (Out_ResizeHeight(o) && XtHeight(w)
+		< (Out_TopMargin(o) + Out_BottomMargin(o) + Out_FontHeight(o) * Out_Rows(o))) {
 		XtHeight(w) = Out_TopMargin(o) + Out_BottomMargin(o)
 			+ Out_FontHeight(o) * Out_Rows(o);
 	}
@@ -1179,7 +1181,6 @@ DrawText(XmTextWidget w, int x, int y, char *ptr, int len, XmHighlightMode highl
 			pieceheight = 10;	/* FIX ME */
 
 			if (count > 0) {
-#if 1
 				/* This is for bug #558840.
 				 * Can be tested in test/Xm/text/test1 by double-clicking.
 				 */
@@ -1190,13 +1191,13 @@ DrawText(XmTextWidget w, int x, int y, char *ptr, int len, XmHighlightMode highl
 				v.background = fg;
 				XChangeGC(XtDisplay(w), Out_DrawGC(o), mask, &v);
 				XFillRectangle(XtDisplay(w), XtWindow(w), Out_DrawGC(o),
-					x + xoff, y - Out_FontAscent(o),
-					piecewidth, y + Out_FontDescent(o));
+					x + xoff, y - Out_Font_Ascent(o),
+					piecewidth, y + Out_Font_Descent(o));
 
 				v.background = bg;
 				v.foreground = fg;
 				XChangeGC(XtDisplay(w), Out_DrawGC(o), mask, &v);
-#endif
+
 				if (Out_FontList(o)->renditions[0]->type == XmFONT_IS_FONT) {
 					XDrawString(XtDisplay(w), XtWindow(w), Out_DrawGC(o),
 						 x + xoff, y, start, count);
@@ -1239,14 +1240,13 @@ DrawText(XmTextWidget w, int x, int y, char *ptr, int len, XmHighlightMode highl
 	{
 	    int left = x;
 	    x = Out_NextTabStop(o, x);
-	    if ( highlight == XmHIGHLIGHT_SELECTED )
-		{
+	    if (highlight == XmHIGHLIGHT_SELECTED) {
 		XSetForeground(XtDisplay(w), Out_DrawGC(o), Prim_Foreground(w));
 		XFillRectangle(XtDisplay(w), XtWindow(w), Out_DrawGC(o),
-			left + xoff, y - Out_FontAscent(o),
+			left + xoff, y - Out_Font_Ascent(o),
 			x - left, Out_FontHeight(o));
 		XSetForeground(XtDisplay(w), Out_DrawGC(o), XtBackground(w));
-		}
+	    }
 
 	    ptr++, len--;
 	}
@@ -1256,11 +1256,10 @@ DrawText(XmTextWidget w, int x, int y, char *ptr, int len, XmHighlightMode highl
 
 	    x = Out_NextTabStop(o, x);
 
-	    if (highlight == XmHIGHLIGHT_SELECTED)
-	    {
+	    if (highlight == XmHIGHLIGHT_SELECTED) {
 		XSetForeground(XtDisplay(w), Out_DrawGC(o), Prim_Foreground(w));
 		XFillRectangle(XtDisplay(w), XtWindow(w), Out_DrawGC(o),
-			left + xoff, y - Out_FontAscent(o),
+			left + xoff, y - Out_Font_Ascent(o),
 			Out_ScrollWidth(o) - ( left + xoff ),
 			Out_FontHeight(o));
 		XSetForeground(XtDisplay(w), Out_DrawGC(o), XtBackground(w));
@@ -1600,7 +1599,7 @@ CursorDraw(XmTextWidget w)
     if (Out_CursorPositionVisible(o))
     {
 	CursorDrawIBeam(w, Out_CursorX(o), 
-		( Out_CursorY(o) - Out_CursorHeight(o) ) + Out_FontDescent(o) );
+		( Out_CursorY(o) - Out_CursorHeight(o) ) + Out_Font_Descent(o) );
 	Out_BlinkOn(o) = True;
     }
 }
@@ -1614,7 +1613,7 @@ CursorErase(XmTextWidget w)
     if (Out_CursorSaveValid(o))
     {
 	CursorRestoreUnderIBeam(w, Out_CursorX(o), 
-		( Out_CursorY(o) - Out_CursorHeight(o) ) + Out_FontDescent(o) );
+		( Out_CursorY(o) - Out_CursorHeight(o) ) + Out_Font_Descent(o) );
     }
 
     Out_BlinkOn(o) = False;
