@@ -1,11 +1,13 @@
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm-2.0/combobox/test6.c,v 1.7 2002/05/01 15:47:31 amai Exp $ */
+
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 
 #include <Xm/BulletinB.h>
 #include <Xm/ComboBoxP.h>
 #include <Xm/List.h>
-#include "XdbPrintResources.c"
+
+#include "../../common/Test.h"
 
 #if !defined(CB_List)
 #define CB_List(w) \
