@@ -42,18 +42,18 @@ main(int argc, char **argv)
 				XmNlabelString, xmstr, NULL);
 
   XtRealizeWidget(toplevel);
-  {
-  static XtWidgetGeometry Expected[] = {
-  	CWWidth | CWHeight,		0,	0,	206,	51,	0,0,0,	/* Form */
-  	CWWidth | CWHeight | CWX | CWY,	10,	10,	185,	30,	0,0,0,	/* two */
+
+/* Note: the following values are the result of
+ * querying the current geometry.
+ */
+{
+static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,    0,    0,  217,   51, 0,0,0, /* Two */
+   CWWidth | CWHeight | CWX | CWY,   10,   10,  196,   30, 0,0,0, /* One */
 };
-
-  PrintDetails(toplevel, Expected);
-  }
-  LessTifTestMainLoop(toplevel);
-  /*
-  XtAppMainLoop(app);
-  */
-
+/* toplevel should be replaced with to correct applicationShell */
+PrintDetails(toplevel, Expected);
+}
+LessTifTestMainLoop(toplevel);
   exit(0);
 }
