@@ -1,7 +1,22 @@
+/* $Id: test5.c,v 1.4 2001/01/02 14:52:25 amai Exp $ */
+/* amai: for me this seems to be a good candidate to
+         demonstrate the problem of 
+	 SF [Bug #114541 ] rounding error in Scale
+	 
+   Note that using the mouse is not a precise method here;
+   I could not adjust the widget to all values I desired.
+   Try the keyboard instead (left/right arrows)!
+   At first we have to make sure that each slider position
+   corresponds to an unique scale value ...
+*/
+
+#include <stdlib.h>
 #include <stdio.h>
+
 #include <Xm/Xm.h>
 #include <Xm/ScaleP.h>
 
+
 void dragCallback(Widget w, XtPointer clientData, XtPointer callData)
 {
     XmScaleCallbackStruct *cbs = (XmScaleCallbackStruct *)callData;
@@ -31,6 +46,7 @@ main(int argc, char **argv)
                                 XmNorientation, XmHORIZONTAL, 
                                 XmNscaleWidth, 100,
 				XmNshowValue, True,
+				XmNwidth, 1000,
 				NULL);
 
   XtAddCallback(one, XmNdragCallback, dragCallback, NULL);
@@ -41,7 +57,16 @@ main(int argc, char **argv)
   XtVaGetValues(one, XmNmaximum, &maximum, NULL);
 
   printf ("one.maximum = %u\n", maximum);
-  XtAppMainLoop(app);
+
+  
+{
+    static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,   50,   50,  100,   35, 0,0,0, /* sb */
+   CWWidth | CWHeight | CWX | CWY,    0,   16,  100,   19, 0,0,0, /* Scrollbar */ 
+    };
+    PrintDetails(toplevel,Expected);
+};
+  LessTifTestMainLoop(toplevel);
 
   exit(0);
 }
