@@ -1,4 +1,4 @@
-/* $Header: /cvsroot/lesstif/lesstif/test/Xm/togglebutton/test7.c,v 1.5 2001/05/15 15:05:21 amai Exp $
+/* $Header: /cvsroot/lesstif/lesstif/test/Xm/togglebutton/test7.c,v 1.6 2002/04/18 19:24:30 amai Exp $
    From:        Yasushi Yamasaki <yamapu@osk3.3web.ne.jp>
    To:          lesstif@hungry.com
    Subject:     bug report
@@ -6,6 +6,7 @@
    Cc:          yamapu@osk3.3web.ne.jp
  */
 
+#include <stdlib.h>
 #include <stdio.h>
 #include <unistd.h>
 
@@ -31,14 +32,14 @@ main(int argc, char *argv[])
 	w = XtCreateWidget("name", xmToggleButtonWidgetClass, shell, NULL, 0);
 	XtDestroyWidget(w);
 	after = sbrk((ptrdiff_t) 0);
-	if ((int)after - (int)before > 0)
+	if ((int)((char *)after - (char *)before) > 0)
 	{
 	    if (iter != 0)
 	    {
 		/*
 		printf("%i %i %p %i\n", iter, iter - diff, after - before, (after - before) / (iter - diff));
 		 */
-		total += (int)after - (int)before;
+		total += (int)((char *)after - (char *)before);
 	    }
 	    diff = iter;
 	}
